getAsync<T extends Object> abstract method

  1. @override
Future<T> getAsync<T extends Object>({
  1. String? name,
})
override

Returns the dependency of type T asynchronously, using the registered override when one exists, or falling back to module.

If name is provided and no override is registered for that name, a CarburetorException is thrown.

Implementation

@override
Future<T> getAsync<T extends Object>({String? name});