CarburetorProviderIsAsyncException class

Exception thrown when a synchronous provider accessor is called on a provider that was registered as asynchronous.

Use CarburetorModule.getAsync instead of CarburetorModule.get to resolve dependencies that are declared with async: true.

Inheritance

Constructors

CarburetorProviderIsAsyncException(String message)
Creates a CarburetorProviderIsAsyncException with the given message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable message describing the error.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited