get<T extends Object> abstract method

T get<T extends Object>()

Returns the dependency of type T from this module.

Throws a CarburetorProviderIsAsyncException if the provider for T was registered as asynchronous. Use getAsync in that case.

Implementation

T get<T extends Object>();