getAsync<T extends Object> abstract method
Returns the dependency of type T from this module asynchronously.
Implementation
Future<T> getAsync<T extends Object>();
Returns the dependency of type T from this module asynchronously.
Future<T> getAsync<T extends Object>();