Module class

Annotation that marks a class as a Carburetor dependency injection module.

Apply this annotation to a class that serves as a module in the Carburetor framework. The build system will generate the corresponding implementation based on the providers declared inside the annotated class.

Example:

@Module()
class AppModule extends CarburetorModule with $AppModuleImplementation {
}
Annotations
  • @Target.new({TargetKind.classType})

Constructors

Module()
Creates a Module annotation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited