singleton property
Whether the dependency is managed as a singleton.
When true, Carburetor creates the instance once and reuses it for every
subsequent resolution. Defaults to false.
Implementation
final bool singleton;
Whether the dependency is managed as a singleton.
When true, Carburetor creates the instance once and reuses it for every
subsequent resolution. Defaults to false.
final bool singleton;