FactoryMethod typedef
FactoryMethod = CarburetorFactoryMethod
Marks a constructor or factory method to be used for dependency instantiation instead of the default constructor.
By default, Carburetor uses the default constructor to create instances of annotated classes. Apply FactoryMethod to a named constructor or factory constructor to override this behavior.
All parameters required by the annotated constructor or method will be automatically resolved and injected by Carburetor at build time.
Only one FactoryMethod annotation may be applied per class. If multiple constructors or methods are annotated, the build will fail.
Implementation
typedef FactoryMethod = CarburetorFactoryMethod;