Provide class
Marks a class as a non-singleton, synchronous dependency.
A new instance is created every time the dependency is requested.
Example:
@Provide()
class MyRepository { ... }
- Inheritance
-
- Object
- CarburetorProvide
- Provide
- Implementers
Constructors
- Provide()
-
Creates a Provide annotation.
const
- Provide.async()
-
Creates an asynchronous, non-singleton provider.
constfactory
Properties
- async → bool
-
Whether the provider factory is asynchronous.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- lazy → bool
-
Whether the singleton instance is created on first access rather than
at module construction time.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleton → bool
-
Whether the dependency is managed as a singleton.
finalinherited
- weak → bool
-
Whether the singleton instance may be garbage-collected when no strong
references to it remain.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited