CarburetorProviderIsAsyncException class
Exception thrown when a synchronous provider accessor is called on a provider that was registered as asynchronous.
Use CarburetorModule.getAsync instead of CarburetorModule.get to
resolve dependencies that are declared with async: true.
- Inheritance
-
- Object
- CarburetorException
- CarburetorProviderIsAsyncException
Constructors
- CarburetorProviderIsAsyncException(String message)
-
Creates a CarburetorProviderIsAsyncException with the given
message.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited