CarburetorModule class abstract
Abstract base class for all Carburetor-generated module implementations.
Carburetor generates a concrete subclass for every class annotated with Module. Use get to resolve synchronous dependencies and getAsync to resolve asynchronous ones.
- Implementers
Constructors
- CarburetorModule()
-
Creates a CarburetorModule.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get<
T extends Object> () → T -
Returns the dependency of type
Tfrom this module. -
getAsync<
T extends Object> () → Future< T> -
Returns the dependency of type
Tfrom this module asynchronously. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited